@@ -641,15 +641,15 @@ public:
 
 	vector<vector<double>> getState() {
 		int maxEntities = 100;
-		vector<vector<double>> returnState(maxEntities, vector<double>(assetList.size() + 5, 0));
+		vector<vector<double>> returnState(maxEntities, vector<double>(6, 0));
 		for (int i = 0; i < entityList.size(); i++) {
 			if (i == maxEntities)break;
-			returnState[i][entityList[i].assetType] = 1;
-			returnState[i][assetList.size()] = max(0.0, entityList[i].timeToComplete - time);
-			returnState[i][assetList.size() + 1] = max(0.0, entityList[i].timeQueueFree - time);
-			returnState[i][assetList.size() + 2] = max(0.0, entityList[i].timeChronoLeft - time);
-			returnState[i][assetList.size() + 3] = entityList[i].energy;
-			returnState[i][assetList.size() + 4] = (double)entityList[i].isComplete;
+			returnState[i][0] = entityList[i].assetType;
+			returnState[i][1] = max(0.0, entityList[i].timeToComplete - time);
+			returnState[i][2] = max(0.0, entityList[i].timeQueueFree - time);
+			returnState[i][3] = max(0.0, entityList[i].timeChronoLeft - time);
+			returnState[i][4] = entityList[i].energy;
+			returnState[i][5] = (double)entityList[i].isComplete;
 		}
 		return returnState;
 	}
